#ifndef __OBJSTORE_H__
#define __OBJSTORE_H__

#include "block_device.h"

#define OBJSTORE_CANWRITE (1)	/* Driver can write to this volume type */
#define OBJSTORE_NEEDSDEV (2)	/* Requires device */

/*
 * objstore_type
 * -------------
 * name - string of objstore type (e.g. "fcfs", "unixfiles")
 * flags - OBJSTORE_ flags (currently only CANWRITE)
 * detect - function to detect if a disk is this type
 *         - returns int (0=false, i.e. not this type)
 *         - objstore_type - this objstore_type struct
 *         - block_device - the block device to examine
 */
struct objstore_type {
	const char* name;
	u64 flags;
	int (detect)(struct objstore_type *, struct block_device *);
	struct super_block *(get_sb)(struct objstore_type *,struct block_device *);
	void (*kill_sb) (struct super_block *);
	struct objstore_type *next;
};

struct objstore_trans {
	struct super_block *sb;
};

struct objstore_ops {
	struct objstore_trans*(newtrans)(struct objstore_trans *t, u64 flags);
	struct objstore_trans*(commit)(struct objstore_trans *t, u64 flags);
	struct objstore_trans*(rollback)(struct objstore_trans *t,u64 flags);
	struct obj *(newobj)(struct objstore_trans *t);
	
};

#endif
